@@ -1,7 +1,7 @@
 from typing import Generic
 
 from web_foundation.kernel import IMessage
-from web_foundation.workers.background.executor.message import BgTask, TaskIMessage
+from web_foundation.app.events.background_task import BgTask, TaskIMessage
 from web_foundation.workers.worker import GenWorker
 
 
@@ -13,6 +13,9 @@ class Service(Generic[GenWorker]):
             TaskIMessage(task, args=args, kwargs=kwargs)
         )
 
+    async def wait_for_response(self, msg: IMessage):
+        return await self.worker.channel.produce_for_response(msg)
+
     @property
     def worker(self) -> GenWorker:
         return self._worker
@@ -23,3 +26,6 @@ class Service(Generic[GenWorker]):
 
     async def emmit_event(self, event: IMessage):
         await self._worker.channel.produce(event)
+
+    # async def microtask(self, task: Coroutine):
+    #     return asyncio.create_task(task)
