@@ -4,28 +4,23 @@ import asyncio
 import copy
 import os
 import socket
-import time
 from functools import partial
-from typing import List, Callable, Any, Type, Dict
+from typing import List, Callable, Any, Type
 
-import loguru
 import orjson
 from dependency_injector import providers
 from pydantic import BaseModel as PDModel
-from sanic import Sanic, Request
+from sanic import Sanic
 from sanic.server.socket import bind_socket
-from sanic.response import BaseHTTPResponse
+
 from web_foundation.app.app import AppContainer
 from web_foundation.app.infrastructure.mdw_manager import ApiMiddlewareManager
-from web_foundation.app.infrastructure.metrics.formatter import GenMetricFormatter, JsonMetricFormatter, MetricFormatter
 from web_foundation.app.infrastructure.metrics.mixin import ApiMetricsMixin
 from web_foundation.kernel import GenericIMessage, IMessage
 from web_foundation.workers.io.http.ext_error_handler import ExtendedErrorHandler
 from web_foundation.workers.io.http.routers.ext_router import ExtRouter
 from web_foundation.workers.io.rt_connection import RtConnection, RtEventCallback
 from web_foundation.workers.worker import Worker
-from web_foundation import settings
-from web_foundation.app.infrastructure.metrics.exporter import MetricExporter, Metric
 
 
 class ServerConfig(PDModel):
@@ -40,15 +35,13 @@ class HttpServer(Worker, ApiMetricsMixin):
     router: ExtRouter | None
     rt_connections: List[RtConnection]
     mdw_manager: ApiMiddlewareManager | None
-    metrics_exporters: Dict[GenMetricFormatter, MetricExporter]
 
     def __init__(self, config: providers.Configuration, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+        super(HttpServer, self).__init__(*args, **kwargs)
         self.config = config
 
     def _configure(self, sock: socket.socket = None, ext_router: ExtRouter = None,
-                   mdw_manager: ApiMiddlewareManager = None,
-                   metrics_exporters: Dict[GenMetricFormatter, MetricExporter] = None):  # type: ignore
+                   mdw_manager: ApiMiddlewareManager = None):  # type: ignore
         self.sock = sock if sock else self.create_socket(self.config.get("host"), self.config.get("port"))
         self.router = copy.deepcopy(ext_router)
         self.sanic_app = Sanic(self.name, router=self.router, dumps=orjson.dumps, loads=orjson.loads)
@@ -56,8 +49,6 @@ class HttpServer(Worker, ApiMetricsMixin):
         self.sanic_app.after_server_stop(self.close)
         self.rt_connections = []
         self.mdw_manager = mdw_manager
-        self.metrics_exporters = metrics_exporters if metrics_exporters else {}
-        self.metrics_exporters.update({JsonMetricFormatter[Dict]: MetricExporter()})
 
     def _post_configure(self):
         self._set_sanic_confs()
